# DataTypes

Daft provides simple DataTypes that are ubiquituous in many DataFrames such as numbers, strings and dates - all the way up to more complex types like tensors and images. Learn more about [DataTypes](../core_concepts.md#datatypes) in Daft User Guide.

::: daft.datatype.DataType
    options:
        filters: ["!^_"]

<!-- add more pages to filters to include them, see dataframe for example -->

<!-- fix: do we need class datatype> -->
